pub struct PartitionEntry {
pub status: u8,
pub chs_first: Chs,
pub type_code: TypeCode,
pub chs_last: Chs,
pub lba_start: u32,
pub lba_count: u32,
}Expand description
A single 16-byte primary partition table entry.
Fields
status: u80x80 = bootable, 0x00 = inactive, other values are invalid.
chs_first: ChsCHS address of the partition’s first sector.
type_code: TypeCodePartition type code.
chs_last: ChsCHS address of the partition’s last sector.
lba_start: u32LBA address of the partition’s first sector.
lba_count: u32Number of sectors in the partition.
Implementations
Sourceimpl PartitionEntry
impl PartitionEntry
Sourcepub fn from_bytes(b: &[u8; 16]) -> Self
pub fn from_bytes(b: &[u8; 16]) -> Self
Decode a 16-byte partition entry slice.
Sourcepub fn is_bootable(&self) -> bool
pub fn is_bootable(&self) -> bool
Returns true if the status byte marks this partition as bootable.
Sourcepub fn is_extended(&self) -> bool
pub fn is_extended(&self) -> bool
true if this entry describes an extended partition container.